==> org-lsst-ccs-subsystem-refrig-gui-4.0.2-sources.jar: org/lsst/ccs/subsystem/refrig/ui/jas/PathMonitorFilter.java <==
package org.lsst.ccs.subsystem.refrig.ui.jas;

import java.util.Collections;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import org.lsst.ccs.gconsole.agent.AgentChannel;
import org.lsst.ccs.gconsole.annotations.ConsoleLookup;
import org.lsst.ccs.gconsole.agent.filter.GenericFilter;
import org.lsst.ccs.gconsole.plugins.monitor.MonitorField;

/**
 * Refrigeration path-oriented monitoring filter.
 *
 * @author The LSST CCS Team
 */
@ConsoleLookup(id="org.lsst.ccs.gconsole.agent.AgentChannelsFilter",
               name="Refrigeration path filter",
               path="Subsystems/MySystem/Monitor",
               description="Refrigeration path filter.")
public class PathMonitorFilter extends GenericFilter {

    private static final String FIELDS = 
        MonitorField.VALUE.getKey()+","+
        MonitorField.UNITS.getKey()+","+
        MonitorField.LOW_ALARM.getKey()+","+
        MonitorField.LOW_WARN.getKey()+","+
        MonitorField.ALERT_LOW.getKey()+","+
        MonitorField.HIGH_WARN.getKey()+","+
        MonitorField.HIGH_ALARM.getKey()+","+
        MonitorField.ALERT_HIGH.getKey()+","+
        MonitorField.NAME.getKey()+","+
        MonitorField.DESCR.getKey();

    private static final Set<String> exclusions = new HashSet<>();
    static {
        exclusions.add("state");
        exclusions.add("configuration");
        exclusions.add("runtimeInfo");
        exclusions.add("RefrigState");
        exclusions.add("ThermalState");
    }

    public PathMonitorFilter(String agents) {
        super("MyName", agents, "", "", true, FIELDS);
    }

    @Override
    public List<String> getDisplayPath(AgentChannel channel) {
        String path = channel.getLocalPath();
        //System.out.println("Channel path: " + path);
        int i1 = path.indexOf("/");
        if (i1 != -1) {
            String section = path.substring(0, i1).trim();
            if (section.equals("main")) {
                int i2 = path.indexOf("/", i1 + 1);
                if (i2 != -1) {
                    section = path.substring(i1 + 1, i2);
                    i1 = i2;
                }
            }
            if (!exclusions.contains(section)) {
                return Collections.singletonList(section + "//" + path.substring(i1 + 1));
            }
        }
        return Collections.emptyList();
    }

}

==> org-lsst-ccs-subsystem-refrig-gui-4.0.5-sources.jar: org/lsst/ccs/subsystem/refrig/ui/jas/PathMonitorFilter.java <==
package org.lsst.ccs.subsystem.refrig.ui.jas;

import java.util.HashSet;
import java.util.Set;
import org.lsst.ccs.gconsole.services.aggregator.AgentChannel;
import org.lsst.ccs.gconsole.base.filter.GenericFilter;
import org.lsst.ccs.gconsole.plugins.monitor.MonitorField;

/**
 * Refrigeration path-oriented monitoring filter.
 *
 * @author The LSST CCS Team
 */
public class PathMonitorFilter extends GenericFilter {

    private static final String FIELDS = 
        MonitorField.VALUE.getKey()+","+
        MonitorField.UNITS.getKey()+","+
        MonitorField.LOW_ALARM.getKey()+","+
        MonitorField.LOW_WARN.getKey()+","+
        MonitorField.ALERT_LOW.getKey()+","+
        MonitorField.HIGH_WARN.getKey()+","+
        MonitorField.HIGH_ALARM.getKey()+","+
        MonitorField.ALERT_HIGH.getKey()+","+
        MonitorField.NAME.getKey()+","+
        MonitorField.DESCR.getKey();

    private static final Set<String> exclusions = new HashSet<>();
    static {
        exclusions.add("state");
        exclusions.add("configuration");
        exclusions.add("runtimeInfo");
        exclusions.add("RefrigState");
        exclusions.add("ThermalState");
    }

    public PathMonitorFilter(String agents) {
        super("MyName", agents, "", "", true, FIELDS);
    }

    @Override
    public String getDisplayPath(AgentChannel channel) {
        String path = channel.getLocalPath();
        //System.out.println("Channel path: " + path);
        int i1 = path.indexOf("/");
        if (i1 != -1) {
            String section = path.substring(0, i1).trim();
            if (section.equals("main")) {
                int i2 = path.indexOf("/", i1 + 1);
                if (i2 != -1) {
                    section = path.substring(i1 + 1, i2);
                    i1 = i2;
                }
            }
            if (!exclusions.contains(section)) {
                return section + "//" + path.substring(i1 + 1);
            }
        }
        return null;
    }

}
